<?php

/*-----------------------------------------------------------------------------------
- Default
----------------------------------------------------------------------------------- */

add_action( 'after_setup_theme', 'townly_theme_setup' );

function townly_theme_setup() {
	global $content_width;

	/* Set the $content_width for things such as video embeds. */
	if ( !isset( $content_width ) )
		$content_width = 750;

	/* Add theme support for automatic feed links. */
	add_theme_support( 'post-formats', array( 'video','audio', 'gallery','quote', 'link', 'aside' ) );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'custom-background' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	add_theme_support( 'responsive-embeds' );
	
	
	/* Add theme support for post thumbnails (featured images). */	
	add_theme_support('post-thumbnails');
	add_image_size('townly_slider', 1900, 850, true ); 		//(cropped)
	add_image_size('townly_header', 1500, 650, true ); 		//(cropped)
	add_image_size('townly_small', 350, 350, true ); 		//(cropped)
	

	/* Add custom menus */
	register_nav_menus(array(
		'main-menu' => esc_html__( 'Main Menu','townly' ),
		'add-menu' => esc_html__( 'Additional Menu','townly' ),
		'bottom-menu' => esc_html__( 'Footer Menu','townly' ),
	));

	/* Add your sidebars function to the 'widgets_init' action hook. */
	add_action( 'widgets_init', 'townly_register_sidebars' );
	
	/* Make theme available for translation */
	load_theme_textdomain('townly', get_template_directory() . '/lang' );

}

function townly_register_sidebars() {
	
	register_sidebar(array(
		'name' => esc_html__( 'Sidebar','townly' ),
		'id' => 'tmnf-sidebar',
		'description' => esc_html__( 'Sidebar widget section','townly' ),
		'before_widget' => '<div class="sidebar_item">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget dekoline">',
		'after_title' => '</h2>'
	));
	

	//footer widgets
	register_sidebar(array(
		'name' => esc_html__( 'Footer 1','townly' ),
		'id' => 'tmnf-footer-1',
		'description' => esc_html__( 'Widget section in footer - left','townly' ),
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	register_sidebar(array(
		'name' => esc_html__( 'Footer 2','townly' ),
		'id' => 'tmnf-footer-2',
		'description' => esc_html__( 'Widget section in footer - center/left','townly' ),
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	register_sidebar(array(
		'name' => esc_html__( 'Footer 3','townly' ),
		'id' => 'tmnf-footer-3',
		'description' => esc_html__( 'Widget section in footer - center/right','townly' ),
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	register_sidebar(array(
		'name' => esc_html__( 'Footer 4','townly' ),
		'id' => 'tmnf-footer-4',
		'description' => esc_html__( 'Widget section in footer - right','townly' ),
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	
	//woo widgets
	if ( class_exists( 'WooCommerce' ) ) {
		register_sidebar(array(
			'name' => esc_html__( 'Shop Sidebar','townly' ),
			'id' => 'tmnf-shop-sidebar',
			'description' => esc_html__( 'Sidebar widget section (displayed on shop pages)','townly' ),
			'before_widget' => '<div class="sidebar_item">',
			'after_widget' => '</div>',
			'before_title' => '<h2 class="widget dekoline dekoline_small">',
			'after_title' => '</h2>'
		));
	}

	//free widget
	register_sidebar(array(
		'name' => esc_html__( 'Free 1','townly' ),
		'id' => 'tmnf-sidebar-free-1',
		'description' => esc_html__( 'Free widget section','townly' ),
		'before_widget' => '<div class="sidebar_item">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	
	register_sidebar(array(
		'name' => esc_html__( 'Free 2','townly' ),
		'id' => 'tmnf-sidebar-free-2',
		'description' => esc_html__( 'Free widget section','townly' ),
		'before_widget' => '<div class="sidebar_item">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	
	register_sidebar(array(
		'name' => esc_html__( 'Free 3','townly' ),
		'id' => 'tmnf-sidebar-free-3',
		'description' => esc_html__( 'Free widget section','townly' ),
		'before_widget' => '<div class="sidebar_item">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	
	register_sidebar(array(
		'name' => esc_html__( 'Free 4','townly' ),
		'id' => 'tmnf-sidebar-free-4',
		'description' => esc_html__( 'Free widget section','townly' ),
		'before_widget' => '<div class="sidebar_item">',
		'after_widget' => '</div>',
		'before_title' => '<h2 class="widget dekoline dekoline_small">',
		'after_title' => '</h2>'
	));
	
}

	
/*-----------------------------------------------------------------------------------
- Framework - Please refrain from editing this section 
----------------------------------------------------------------------------------- */


// Set path to Framework and theme specific functions
$functions_path = get_template_directory() . '/functions/';

// Theme specific functionality
require_once ($functions_path . 'admin-functions.php');					// Custom functions and plugins

// Add Redux options panel
if ( !isset( $themnific_redux ) && file_exists( get_template_directory()  . '/redux-framework/redux-themnific.php' ) ) {
    require_once( get_template_directory()  . '/redux-framework/redux-themnific.php' );
}

	
/*-----------------------------------------------------------------------------------
- Enqueues scripts and styles for front end
----------------------------------------------------------------------------------- */ 

function townly_enqueue_style() {
	
	// Main stylesheet
	wp_enqueue_style( 'townly-style', get_stylesheet_uri());
	wp_style_add_data( 'townly-style', 'rtl', 'replace' ); 
	
	// townly-addons css	
	wp_enqueue_style('townly-addons', get_template_directory_uri() .	'/styles/townly-addons.css');
	wp_style_add_data( 'townly-addons', 'rtl', 'replace' ); 
	
	// Font Awesome css	
	wp_enqueue_style('fontawesome', get_template_directory_uri() .	'/styles/fontawesome.css');
	
}
add_action( 'wp_enqueue_scripts', 'townly_enqueue_style' );




// themnific custom css + chnage the order of how the sytlesheets are loaded, and overrides WooCommerce styles.
function townly_custom_order() {
	
	// place wooCommerce styles before our main stlesheet
	if ( class_exists( 'WooCommerce' ) ) {
		wp_dequeue_style( 'woocommerce_frontend_styles' );
		wp_enqueue_style('woocommerce-frontend-styles', plugins_url() .'/woocommerce/assets/css/woocommerce.css');
	
		wp_enqueue_style('townly-woo-custom', get_template_directory_uri().	'/styles/woo-custom.css');
		wp_enqueue_style('townly-mobile', get_template_directory_uri().'/style-mobile.css');
		wp_style_add_data( 'townly-mobile', 'rtl', 'replace' ); 
	} else {
		wp_enqueue_style('townly-mobile', get_template_directory_uri().'/style-mobile.css');
		wp_style_add_data( 'townly-mobile', 'rtl', 'replace' ); 
	}
}
add_action('wp_enqueue_scripts', 'townly_custom_order');


function townly_enqueue_script() {	

		// Load Common scripts	
		wp_enqueue_script('townly-ownscript', get_template_directory_uri() .'/js/ownScript.js',array( 'jquery' ),'', true);
		

		// Singular comment script		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );

}
	
add_action('wp_enqueue_scripts', 'townly_enqueue_script');



/*-----------------------------------------------------------------------------------
- Include accessible
----------------------------------------------------------------------------------- */

include_once (get_template_directory() . '/functions/aria-walker-nav-menu.php');


/*-----------------------------------------------------------------------------------
- TGM_Plugin_Activation class.
----------------------------------------------------------------------------------- */
require_once get_template_directory()  . '/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'townly_register_required_plugins' );
function townly_register_required_plugins() {

    $plugins = array(
	

        // redux-framework
        array(
            'name'				=> esc_html__( 'Redux Framework','townly' ),
            'slug'      		=> 'redux-framework',
            'required'  		=> true,
        ),
        // elementor
        array(
            'name'				=> esc_html__( 'Elementor','townly' ),
            'slug'      		=> 'elementor',
            'required'  		=> true,
        ),            
		// townly-addons
        array(
            'name'				=> esc_html__( 'Townly Addons','townly' ),
            'slug'      		=> 'townly-addons',
			'source'            => get_template_directory() . '/plugin/townly-addons.zip', // The plugin source.
            'required'  		=> true,
        ),     
        // one-click-demo-import
        array(
            'name'				=> esc_html__( 'One Click Demo Import','townly' ),
            'slug'      		=> 'one-click-demo-import',
            'required'  		=> false,
        ),     
        // events-manager
        array(
            'name'				=> esc_html__( 'Events Manager','townly' ),
            'slug'      		=> 'events-manager',
            'required'  		=> false,
        ),

    );
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins','townly' ),
            'menu_title'                      => esc_html__( 'Install Plugins','townly' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s','townly' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.','townly' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.','This theme requires the following plugins: %1$s.','townly' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.','This theme recommends the following plugins: %1$s.','townly' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','townly' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','townly' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','townly' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','townly' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','townly' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','townly' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins','townly' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins','townly' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer','townly' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.','townly' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s','townly' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa( $plugins, $config );

}

	
/*-----------------------------------------------------------------------------------
- Other theme functions
----------------------------------------------------------------------------------- */

// icons - font awesome
if ( ! function_exists ( 'townly_icon' ) ) {
	function townly_icon() {
		if(has_post_format('audio')) {return '<i title="'. esc_attr__('Audio','townly').'" class="tmnf_icon fas fa-volume-up"></i>';
		}elseif(has_post_format('gallery')) {return '<i title="'. esc_attr__('Gallery','townly').'" class="tmnf_icon fas fa-camera"></i>';
		}elseif(has_post_format('image')) {return '<i title="'. esc_attr__('Image','townly').'" class="tmnf_icon fas fa-camera"></i>';	
		}elseif(has_post_format('link')) {return '<i title="'. esc_attr__('Link','townly').'" class="tmnf_icon fas fa-link"></i>';			
		}elseif(has_post_format('quote')) {return '<i title="'. esc_attr__('Quote','townly').'" class="tmnf_icon fas fa-quote-right"></i>';		
		}elseif(has_post_format('video')) {return '<i title="'. esc_attr__('Video','townly').'" class="tmnf_icon fas fa-play-circle"></i>';
		} 	
	}
}


// register custom fonts for Gutenberg

function townly_gutenberg_styles() {

	// Load the theme styles within Gutenberg.
	wp_enqueue_style( 'townly-gutenberg', get_theme_file_uri( '/styles/style-editor.css' ), false, '1.1.1', 'all' );

	// Add custom fonts to Gutenberg.
	wp_enqueue_style( 'townly-fonts', townly_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'townly_gutenberg_styles' );

/**
 * Register custom fonts.
 */
function townly_fonts_url() {
	$fonts_url = '';
	$secondfont = esc_html_x( 'on', 'DM Sans: on or off', 'townly' );

	if ( 'off' !== $secondfont ) {
		$font_families = array();

		if ( 'off' !== $secondfont ) {
			$font_families[] = 'DM Sans:400,400i,500,600,700';
		}

		$query_args = array(
			'family' => rawurlencode( implode( '|', $font_families ) ),
			'subset' => rawurlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
}




// new excerpt function

// Old Shorten Excerpt text for use in theme
function townly_excerpt($text, $chars = 1620) {
	$text = $text." ";
	$text = substr($text,0,$chars);
	$text = substr($text,0,strrpos($text,' '));
	$text = $text."";
	return $text;
}

function townly_trim_excerpt($text) {
     $text = str_replace('[', '', $text);
     $text = str_replace(']', '', $text);
     return $text;
    }
add_filter('get_the_excerpt', 'townly_trim_excerpt');


// override woocommerce image
add_filter( 'woocommerce_get_image_size_gallery_thumbnail', function( $size ) {
	return array(
		'width'  => 160,
		'height' => 160,
		'crop'   => 1,
	);
} );

// meta sections
if ( ! function_exists ( 'townly_meta_date' ) ) {
	function townly_meta_date() { ?>   
		<p class="meta <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
			<span class="post-date"><?php the_time(get_option('date_format')); ?></span>
		</p>
	<?php }
}

if ( ! function_exists ( 'townly_meta_front' ) ) {
	function townly_meta_front() { ?>    
		<p class="meta <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
			<span class="post-date"><?php the_time(get_option('date_format')); ?><span class="divider">•</span></span>
			<span class="categs"><?php the_category(', ') ?></span>
		</p>
	<?php
	}
}

if ( ! function_exists ( 'townly_meta_full' ) ) {
	function townly_meta_full() { ?>    
		<p class="meta meta_full <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
			<span class="post-date"><?php the_time(get_option('date_format')); ?><span class="divider">•</span></span>
			<span class="categs"><?php the_category(', ') ?><span class="divider">•</span></span>
			<?php 
			echo '<span class="author">'; the_author_posts_link();echo '</span>';
			?>
		</p>
	<?php
	}
}

if ( ! function_exists ( 'townly_meta_more' ) ) {
	function townly_meta_more() { ?>
		<p class="meta meta_more <?php $themnific_redux = get_option( 'themnific_redux' ); if(isset($themnific_redux['tmnf-post-meta-dis']) ? $themnific_redux['tmnf-post-meta-dis'] : null) echo 'tmnf_hide';?>">
		<a class="ribbon" href="<?php the_permalink() ?>"><?php esc_html_e('Read More','townly');?> <span class="read_more_arrow"> <i class="fas fa-arrow-right"></i></span> <span class="screen-reader-text"><?php the_title_attribute(); ?></span></a>
		</p>
	<?php }
}



// menu description
function townly_nav_description( $item_output, $item, $depth, $args ) {
    if ( !empty( $item->description ) ) {
        $item_output = str_replace( $args->link_after . '</a>', '<span class="menu-item-description">' . $item->description . '</span>' . $args->link_after . '</a>', $item_output );
    }
 
    return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'townly_nav_description', 10, 4 );

//Breadcrumbs
if ( ! function_exists ( 'townly_breadcrumbs' ) ) {
	function townly_breadcrumbs() {
		if (!is_home()) {
			echo '<span class="crumb"><a href="'. esc_url(home_url('/')).'">';
			echo esc_html__('Home','townly');
			echo "</a></span>
	 ";
			if ('wpm_project' == get_post_type()) {
			echo '<span class="crumb">';
				$themnific_redux = get_option( 'themnific_redux' );
				if(empty($themnific_redux['tmnf-project-url'])) {echo esc_html__('Projects','townly');} else {
					echo '<a href="'. esc_url($themnific_redux['tmnf-project-url']).'">';
					echo esc_html__('Projects','townly');
					echo '</a>';
				}
			echo '</span>';
			}
			if ('event' == get_post_type()) {
			echo '<span class="crumb">';
				$themnific_redux = get_option( 'themnific_redux' );
				if(empty($themnific_redux['tmnf-events-url'])) {echo esc_html__('Events','townly');} else {
					echo '<a href="'. esc_url($themnific_redux['tmnf-events-url']).'">';
					echo esc_html__('Events','townly');
					echo '</a>';
				}
			echo '</span>';
			}
			if (is_category() || is_single()) {
				echo '<span class="crumb">'; the_category(', '); echo '</span>';
				if (is_single()) {
					echo '<span class="crumb">';
					echo the_title().'</span>';
				}
		} elseif (is_page()) {
			global $post;
			if($post->post_parent){
				echo '<span class="crumb"> <a href="'. get_permalink( $post->post_parent ) .'">';
				echo get_the_title($post->post_parent).'</a></span><span class="crumb">';
				echo the_title().'</span>';
			} else {
				echo '<span class="crumb">';
				echo the_title();
				echo '</span>';
			}
		} 
		}
	}
}


// span to default widgets
function townly_cat_count_span($links) {
  $links = str_replace('</a> (', '</a> <span class="cat_nr">', $links);
  $links = str_replace(')', '</span>', $links);
  return $links;
}
add_filter('wp_list_categories', 'townly_cat_count_span');



function townly_archive_count($links) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="cat_nr">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}
add_filter('get_archives_link', 'townly_archive_count');

// remove default styling Events Manager
add_filter('em_get_template_classes', '__return_empty_array');



function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328475&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>