<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return; 
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "themnific_redux";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Townly - admin panel', 'townly' ),
        'page_title'           => __( 'Townly admin panel', 'townly' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '_options',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
                    'href'   => 'http://themestate.com/docs/townly/',
					'target'   => '_blank',
                    'title' => esc_html__( 'Documentation', 'townly' ),
    );

    $args['admin_bar_links'][] = array(
                    'href'   => 'http://themnific.com/',
					'target'   => '_blank',
                    'title' => esc_html__( 'Our Themes', 'townly' ),
    );

    // Add content after the form.
    $args['footer_text'] = __( '<p>Themnific Themes</p>', 'townly' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    // -> START Fields
    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'General Settings','townly' ),
                    'icon'   => 'el el-cogs',
                    'fields' => array( // header end
					
                        array(
                            'id'       => 'tmnf-main-logo',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
							'url'      => true,
                            'title'    => esc_html__( 'Main Logo','townly' ),
                            'desc'     => esc_html__( 'Upload a logo for your theme','townly' ),
                        ),
												
                      	array(
                            'id'       => 'tmnf-container-width',
                            'type'     => 'radio',
                            'title'    => esc_html__('Container Width Limitation','townly'),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                'tmnf_width_normal' => esc_html__('Normal (1140px)','townly'),
                                'tmnf_width_wide' => esc_html__('Wide (1440px)','townly'),
                            ),
                            'default'  => 'tmnf_width_wide'
                        ),
						
						array(
                            'id'       => 'tmnf-header-image',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
							'url'      => true,
                            'title'    => esc_html__( 'Header image', 'townly' ),
                            'subtitle'     => esc_html__( 'Upload a "header" image for blog and archives. Recommended size 1500x650px', 'townly' ),
                        ),
						
                        array(
                            'id'       => 'tmnf-menu-label',
                            'type'     => 'text',
                            'title'    => esc_html__('Menu Label ', 'townly' ),
                            'subtitle'     => esc_html__('Write menu label above logo/site title.', 'townly' ),
                            'default'  => '',
                        ),
						
                        array(
                            'id'       => 'tmnf-uppercase',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Uppercase Fonts','townly' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),

                        array(
                            'id'       => 'townly-site-wrapper',
							'type'      => 'color',
							'title'     => esc_html__('Site Frame: Background Color','townly'),
                            'transparent'=> false,
							'default'   => '#f7f7f7',
							'output'    => array(
								'background-color' => '.site_wrapper'
							)
						),
						

                        array(
                            'id'       => 'townly-spacing-site-wrapper',
                            'type'     => 'spacing',
                            'output'   => array( '.site_wrapper' ),
                            'mode'     => 'padding',
                            'all'      => true,   
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Site Frame: Spacing','townly' ),
                            'subtitle' => esc_html__( 'Site Frame is applied only on large desktop screens','townly' ),
                            'default'        => array(
                                'padding'  => '0',
                            )
                        ),

						array(
							'id'   => 'info_blog_section',
							'type' => 'info',
							'title' => esc_html__('Blog Section (+ Archives)','townly'),
							'style' => 'success',
						),
						
                        array(
                            'id'       => 'tmnf-blog-label',
                            'type'     => 'text',
                            'title'    => esc_html__('News / Blog Title', 'townly' ),
                            'subtitle'     => esc_html__('Write any label for blog/news page title.', 'townly' ),
                            'default'  => esc_html__('City News', 'townly' ),
                        ),
						
                        array(
                            'id'       => 'tmnf-blog-sublabel',
                            'type'     => 'text',
                            'title'    => esc_html__('News / Blog Sub-title', 'townly' ),
                            'default'  => esc_html__('Recent news and happenings', 'townly' ),
                        ),
												
                        array(
                          'id'       => 'tmnf-blog-layout',
                          'type'     => 'radio',
                          'title'    => esc_html__('Blog Layout','townly'),
                          'subtitle' => esc_html__('Select layout and styling for blog template','townly'),
                          //Must provide key => value pairs for radio options
                          'options'  => array(
                              'blog_layout_list' => esc_html__('Blog Style: Lists','townly'),
                              'blog_layout_classic' => esc_html__('Blog Style: Classic','townly'),
                          ),
                          'default'  => 'blog_layout_list'
                      ),
						
                    )
					
					// section end
    ) );
	
	

    Redux::setSection( $opt_name, array(
					'type' => 'divide',
    ) );
	
	
	
	
    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Primary Styling','townly' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end


						array(
                            'id'          => 'townly-body-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Typography','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
							'all_styles'  => true,
                            'output'      => array( 'body,input,button,select,textarea,#wpmem_reg fieldset,#wpmem_login fieldset,fieldset .give-final-total-amount' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography used as general text.','townly' ),
                            'default'     => array(
                                'color'       => '#232323',
                                'font-style'  => '400',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '18px',
                            ),
                        ),

                        array(
                            'id'       => 'townly-background',
                            'type'     => 'background',
                            'title'    => esc_html__( 'Main Body Background','townly' ),
                            'subtitle' => esc_html__( 'Body background with image, color, etc.','townly' ),
                            'transparent'=> false,
                            'output'   => array('.wrapper,.postbar' ),
                            'default'     => array(
                                'background-color'       => '#fff',
                            ),
                        ),
						
						array(
							'id'        => 'townly-color-ghost',
							'type'      => 'color',
							'title'     => esc_html__('Ghost Background Color','townly'),
							'subtitle'  => esc_html__('Pick a alternative background color (similar to Main Body Background)','townly'),
                            'transparent'=> false,
							'default'   => '#f3f7fa',
							'output'    => array(
								'background-color' => '.ghost,.single .give-goal-progress,#comments .navigation a,a.page-numbers,.page-numbers.dots,#menu-widget-menu'
							)
						),

                        array(
                            'id'       => 'townly-link-color',
                            'type'     => 'link_color',
                            'title'    => esc_html__( 'Links Color Option','townly' ),
                            'subtitle' => esc_html__( 'Pick a link color','townly' ),
                            'transparent'=> false,
							'output'   => array( 'a,.events-table h3 a' ),
                            'default'  => array(
                                'regular' => '#030233',
                                'hover'   => '#505377',
                                'active'  => '#000',
                            )
                        ),
						

						
						array(
							'id'        => 'townly-color-entry-link',
							'type'      => 'color',
							'title'     => esc_html__('Entry Links (in post texts)','townly'),
							'subtitle'  => esc_html__('Pick a custom color for post links.','townly'),
                            'transparent'=> false,
							'default'   => '#E8816E',
							'output'    => array(
								'color' => '.entry p a:not(.wp-block-button__link):not(.evnt_link),.entry li a:not(.wp-block-button__link):not(.evnt_link)',
								'border-color' => '.events-table h3 a:hover',
							)
						),
						

						
						array(
							'id'        => 'townly-color-entry-link-hover',
							'type'      => 'color',
							'title'     => esc_html__('Entry Links (in post texts): Hover Background Color','townly'),
							'subtitle'  => esc_html__('Pick a custom color for post links.','townly'),
                            'transparent'=> false,
							'default'   => '#1a1e24',
							'output'    => array(
								'background-color' => '.entry p a:hover',
							)
						),
						
                        array(
                            'id'       => 'townly-primary-border',
							'type'      => 'color',
							'title'     => esc_html__('Borders Color','townly'),
							'subtitle'  => esc_html__('Pick a color for primary borders','townly'),
                            'transparent'=> false,
							'default'   => '#e1ebf2',
							'output'    => array(
								'border-color' => '.p-border,.sidebar_item,.sidebar_item li,.sidebar_item p,.give-goal-progress,.meta,h3#reply-title,.tagcloud a,.taggs a,.page-numbers,input,textarea,select,table,table th,table td,dl,dt,.nav_item a,.tp_recent_tweets ul li,.page-link a span,.post-pagination>p a,.addtoany_share_save_container',
							)
						),
						
						array(
							'id'        => 'townly-text-sidebar',
							'type'      => 'color',
							'title'     => esc_html__('Sidebar Text Color','townly'),
							'subtitle'  => esc_html__('Pick a color for sidebar text.','townly'),
                            'transparent'=> false,
							'default'   => '#1a1e24',
							'output'    => array(
								'color' => '#sidebar,.post-pagination span',
							)
						),
						
						array(
							'id'        => 'townly-links-sidebar',
							'type'      => 'color',
							'title'     => esc_html__('Sidebar Links: Color','townly'),
							'subtitle'  => esc_html__('Pick a color for sidebar links.','townly'),
                            'transparent'=> false,
							'default'   => '#2a2c44',
							'output'    => array(
								'color' => '.widgetable a',
							)
						),
						
						array(
							'id'        => 'townly-links-hover-sidebar',
							'type'      => 'color',
							'title'     => esc_html__('Sidebar Links: Hover Color','townly'),
                            'transparent'=> false,
							'default'   => '#505377',
							'output'    => array(
								'color' => '.widgetable a:hover',
							)
						),


                    )

					// section end
    ) );
	// Primary styling THE END
	
	
	
	
	
	
	// HEADER STYLING
    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Header Styling','townly' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
										
                        array(
                            'id'       => 'tmnf-header-layout',
                            'type'     => 'radio',
                            'title'    => esc_html__('Header Layout','townly'),
                            'subtitle' => esc_html__('Select layout for your header','townly'),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                'header_default' => esc_html__('Default Header','townly'),
                                'header_fullwidth' => esc_html__('Full Width Header','townly'),
                                'header_fullwidth_2' => esc_html__('Full Width Header 2','townly'),
                                'header_transparent' => esc_html__('Transparent Header','townly'),
                            ),
                            'default'  => 'header_fullwidth'
                        ),
						
						array(
							'id'        => 'townly-bg-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Header Background Color','townly'),
							'subtitle'  => esc_html__('Pick a bg color for header. On mobile devices is transparent header disabled.','townly'),
                            'transparent'=> false,
							'default'   => '#fff',
							'output'    => array(
								'background-color' => '.container_head,#header,.header_transparent #header.scrolled',
							)
						),
						
						array(
							'id'        => 'townly-link-title',
							'type'      => 'color',
							'title'     => esc_html__('Title Link Color','townly'),
							'subtitle'  => esc_html__('Pick a color for header links.','townly'),
                            'transparent'=> false,
							'default'   => '#030233',
							'output'    => array(
								'color' => '#header h1 a',
							)
						),

						array(
                            'id'          => 'townly-header-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Navigation Typography','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( '.nav>li>a,.bottomnav p' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography used as navigation text.','townly' ),
                            'default'     => array(
                                'color'       => '#030233',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '17px',
                            ),
                        ),
						
						array(
							'id'        => 'townly-hover-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Navigation Links: Hover Color','townly'),
							'subtitle'  => esc_html__('Pick a hover color for header links.','townly'),
                            'transparent'=> false,
							'default'   => '#f8ff31',
							'output'    => array(
								'border-color' => '.nav li.current-menu-item>a,#main-nav>li>a:hover',
							)
						),
						

					
						array(
							'id'   => 'info_sub_menu',
							'type' => 'info',
							'title' => esc_html__('Sub-menu + Special menu button','townly'),
							'style' => 'success',
						),
						
						
						
						array(
							'id'        => 'townly-sub-bg-myheader',
							'type'      => 'color',
							'title'     => esc_html__('Sub-menu Background Color','townly'),
							'subtitle'  => esc_html__('Pick a color for header text.','townly'),
                            'transparent'=> false,
							'default'   => '#1c2123',
							'output'    => array(
								'background-color' => '.nav li ul',
								'border-left-color' => '.nav>li>ul:after,.nav > li.mega:hover::after',
								'border-right-color' => 'body.rtl .nav>li>ul:after,body.rtl .nav > li.mega:hover::after',
							)
						),


						array(
                            'id'          => 'townly-sub-header-typography',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Sub-menu Typography','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( '.nav ul li>a,.topnav .menu_label,.topnav .social-menu span' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography used as navigation text.','townly' ),
                            'default'     => array(
                                'color'       => '#fff',
                                'font-weight'  => '400',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '14px',
                            ),
                        ),
						

						
						
						array(
							'id'        => 'townly-special-bg',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button: Background Color','townly'),
							'subtitle'  => esc_html__('Pick a color for header text.','townly'),
                            'transparent'=> false,
							'default'   => '#f8ff31',
							'output'    => array(
								'background-color' => '#main-nav>li.special>a',
							)
						),
						
						
						array(
							'id'        => 'townly-special-text',
							'type'      => 'color',
							'title'     => esc_html__('Menu Button: Hover Text Color','townly'),
							'subtitle'  => esc_html__('Pick a color for header text.','townly'),
                            'transparent'=> false,
							'default'   => '#000',
							'output'    => array(
								'color' => '#main-nav>li.special>a',
							)
						),
						
						array(
							'id'   => 'info_normal',
							'type' => 'info',
							'title' => esc_html__('Topbar','townly'),
							'style' => 'success',
						),	
						
						
                        array(
                            'id'       => 'tmnf-topnav-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Disable Topbar','townly' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),	
						
						array(
							'id'        => 'townly-topnav-bg',
							'type'      => 'color',
							'title'     => esc_html__('Topbar Background Color','townly'),
                            'transparent'=> false,
							'default'   => '#f3f7fa',
							'output'    => array(
								'background-color' => '.topnav,#topnav .container',
							)
						),	
						
						array(
							'id'        => 'townly-topnav-text',
							'type'      => 'color',
							'title'     => esc_html__('Topbar Links/Text Color','townly'),
                            'transparent'=> false,
							'default'   => '#1a1e24',
							'output'    => array(
								'color' => '#topnav p,#topnav a,#topnav span,#topnav a:hover',
							)
						),


						array(
							'id'   => 'info_normal',
							'type' => 'info',
							'title' => esc_html__('Spacing of the Header','townly'),
							'style' => 'success',
						),

                        array(
                            'id'             => 'townly-width-header',
                            'type'           => 'dimensions',
                            'output'   => array( '#titles' ),
                            'units'          => 'px', 
                            'units_extended' => 'true',  
                            'height'          => false, 
                            'title'          => esc_html__( 'Header Title/Logo Width Option','townly' ),
                            'subtitle'       => esc_html__( 'Choose the width limitation for header logo.','townly' ),
                            'default'        => array(
                                'width'  => '200px',
                            )
                        ),

                        

                        array(
                            'id'       => 'townly-spacing-logo',
                            'type'     => 'spacing',
                            'output'   => array( '#titles' ),
                            'mode'     => 'margin',
                            'all'      => false, 
                            'right'         => false,    
                            'left'          => false,   
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Header: Title/Logo Margin','townly' ),
                            'default'  => array(
                                'margin-top'    => '40px',
                                'margin-bottom' => '40px',
                            )
                        ),
						

                        array(
                            'id'       => 'townly-spacing-nav',
                            'type'     => 'spacing',
                            'output'   => array( '#navigation' ),
                            'mode'     => 'padding',
                            'all'      => false,
                            'right'         => false,    
                            'left'          => false,     
                            'units'         => 'px',      
                            'title'    => esc_html__( 'Header Navigation Spacing','townly' ),
                            'subtitle' => esc_html__( 'Choose the margin for header navigation.','townly' ),
                            'default'  => array(
                                'padding-top'    => '17px',
                                'padding-bottom' => '10px',
                            )
                        ),

                    )
					// section end
    ) );
	// header styling THE END
	
	
	
	
	

    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Footer Styling','townly' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
						

					    array(
                            'id'       => 'tmnf-footer-logo',
                            'type'     => 'media',
							'default'  => '',
							'readonly' => false,
                            'preview'  => true,
                            'title'    => esc_html__( 'Footer Logo','townly' ),
                            'desc'     => esc_html__( 'Upload a footer logo for your theme.','townly' ),
                        ),

                        array(
                            'id'             => 'townly-width-footer-logo',
                            'type'           => 'dimensions',
                            'output'   => array( '.footer-logo img' ),
                            'units'          => 'px', 
                            'units_extended' => 'true',  
                            'height'          => false, 
                            'title'          => esc_html__( 'Footer Logo: Width','townly' ),
                            'default'        => array(
                                'width'  => '120px',
                            )
                        ),
						
						array(
							'id'        => 'townly-color-myfooter',
							'type'      => 'background',
							'title'     => esc_html__('Footer Background Color','townly'),
							'subtitle'  => esc_html__('Pick a background color for footer.','townly'),
                            'transparent'=> false,
                            'output'   => array('#footer,#footer .searchform input.s' ),
                            'default'     => array(
                                'background-color'       => '#222233',
                            ),
						),
						
						array(
							'id'        => 'townly-text-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Text - Color','townly'),
							'subtitle'  => esc_html__('Pick a color for footer links.','townly'),
                            'transparent'=> false,
							'default'   => '#ffffff',
							'output'    => array(
								'color' => '#footer p,#footer',
							)
						),
						
						array(
							'id'        => 'townly-links-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Links - Color','townly'),
							'subtitle'  => esc_html__('Pick a color for footer links.','townly'),
                            'transparent'=> false,
							'default'   => '#d5d5e2',
							'output'    => array(
								'color' => '#footer a,#footer h2,#footer h3,#footer h4,#footer .meta,#footer .meta a,#footer .searchform input.s',
							)
						),
						
						array(
							'id'        => 'townly-hover-myfooter',
							'type'      => 'color',
							'title'     => esc_html__('Footer Links - Hover Color','townly'),
							'subtitle'  => esc_html__('Pick a hover color for footer links.','townly'),
                            'transparent'=> false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '#footer a:hover',
							)
						),
						
						
                        array(
                            'id'       => 'townly-footer-border',
							'type'      => 'color',
							'title'     => esc_html__('Footer Borders','townly'),
							'subtitle'  => esc_html__('Pick a color for footer borders.','townly'),
                            'transparent'=> false,
							'default'   => '#2a2a47',
							'output'    => array(
								'border-color' => '#footer li.cat-item,.footer-logo,#copyright,#footer .tagcloud a,#footer .tp_recent_tweets ul li,#footer .p-border,#footer .searchform input.s,#footer input,#footer table,#footer table th,#footer table td',
                                'background-color' => '.footop-left,.footop-left::after',
							)
						), 
						
						array(
							'id'   => 'info_normal',
							'type' => 'info',
							'title' => esc_html__('Special Footer Section (above the footer)','townly'),
							'style' => 'success',
						),	
						
						
						array(
							'id'        => 'townly-bg-color-abovefooter',
							'type'      => 'color',
							'title'     => esc_html__('Special Footer Background Color','townly'),
                            'transparent'=> false,
							'default'   => '#f8ff31',
							'output'    => array(
								'background-color' => '.footop',
							)
						),
						
						
						array(
							'id'        => 'townly-text-color-abovefooter',
							'type'      => 'color',
							'title'     => esc_html__('Special Footer Text / links Color','townly'),
                            'transparent'=> false,
							'default'   => '#000',
							'output'    => array(
								'color' => '#footop h2,#footop a,#foo-spec',
							)
						),


			
						array(
                            'id'       => 'tmnf-footer-editor',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Footer Text','townly' ),
                            'subtitle' => esc_html__( 'Just like a text box widget.','townly' ),
                            'desc'     => esc_html__( 'This field is HTML validated!','townly' ),
							'default'  => '',
                            'validate' => 'html',
						),
						
						array(
                            'id'       => 'tmnf-footer-credits',
                            'type'     => 'textarea',
                            'title'    => esc_html__( 'Footer Credits Text','townly' ),
                            'subtitle' => esc_html__( 'Just like a text box widget.','townly' ),
                            'desc'     => esc_html__( 'This field is HTML validated!','townly' ),
							'default'  => 'Copyright © 2022 - Townly Theme',
                            'validate' => 'html',
						),



                    )

					// section end
    ) );
	// footer styling THE END
	
	
	
	
	

    Redux::setSection( $opt_name, array(                    
					'title'  => esc_html__( 'Typography','townly' ),
                    'icon'   => 'el el-bold',
                    'fields' => array( // header end
					
					
						array(
                            'id'          => 'townly-h1',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H1 Font Style','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h1' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H1.','townly' ),
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '24px',
                            ),
                        ),
						
						array(
                            'id'          => 'townly-h2-large',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Post Titles','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h1.entry-title,h1.archiv,.eleslideinside h2,.eleslideinside h3' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H2.','townly' ),
                            'default'     => array(
                                'color'       => '#222',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '60px',
                            ),
                        ),
						
						array(
                            'id'          => 'townly-h2-list',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Lists: Post Titles','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h2.posttitle' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H2.','townly' ),
                            'default'     => array(
                                'color'       => '#222',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '40px',
                            ),
                        ),
						
						array(
                            'id'          => 'townly-h2',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H2 Font Style','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h2,.entry h1,.entry h2,.entry h3,.entry h4,.entry h5,.entry h6' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H2.','townly' ),
                            'default'     => array(
                                'color'       => '#222',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '22px',
                            ),
                        ),
						
						array(
                            'id'          => 'townly-h3',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H3 Font Style','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h3,.format-quote .teaser,#wpmem_reg legend, #wpmem_login legend,.give-goal-progress' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H3.','townly' ),
                            'default'     => array(
                                'color'       => '#222',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '22px',
                            ),
                        ),
						
						array(
                            'id'          => 'townly-h4',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H4 Font Style','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h4,.comment-author cite,.tptn_posts_widget li::before,.sidebar_item .menu>li>a' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H4.','townly' ),
                            'default'     => array(
                                'color'       => '#222',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '17px',
                            ),
                        ),
						
						array(
                            'id'          => 'townly-h5',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H5 Font Style + Buttons','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h5,.tab-post h4,.tptn_title,.submit,.nav-previous a,.post-pagination,.mc4wp-form input,.woocommerce #respond input#submit, .woocommerce a.button,.woocommerce button.button, .woocommerce input.button,.tmnf_events_widget a,.post-nav-text,a.event_button,.give-btn' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H5.','townly' ),
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '700',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '15px',
                            ),
                        ),	
						
						array(
                            'id'          => 'townly-h6',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'H6 Font Style','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( 'h6,.su-button span,.owl-nav>div,.awesome-weather-wrap' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for heading H6.','townly' ),
                            'default'     => array(
                                'color'       => '#000',
                                'font-weight'  => '500',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '11px',
                            ),
                        ),


                    )

					// section end
    ) );
	// typography styling THE END
	
	
	
	

    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Other Styling','townly' ),
                    'icon'   => 'el el-tint',
                    'fields' => array( // header end
						
	
						array(
                            'id'          => 'townly-meta',
                            'type'        => 'typography',
                            'title'       => esc_html__( 'Meta Sections - Font Style','townly' ),
                            'google'      => true,
                            'font-backup' => true,
                            'text-align'  => false,
                            'output'      => array( '.meta,.meta a,.crumb' ),
                            'units'       => 'px',
                            'line-height' => false,
                            'subtitle'    => esc_html__( 'Select the typography for meta sections.','townly' ),
                            'default'     => array(
                                'color'       => '#2a2c44',
                                'font-weight'  => '500',
                                'font-family' => 'DM Sans',
                                'google'      => true,
                                'font-size'   => '13px',
                            ),
                        ),

						array(
							'id'        => 'townly-color-divider',
							'type'      => 'color',
							'title'     => esc_html__('Dividers: Background Color','townly'),
                            'transparent'=> false,
							'default'   => '#202056',
							'output'    => array(
								'background-color' => '.dekoline:before,.eleslideinside h2:before,a.mainbutton.inv,#menu-widget-menu>li>a:hover,#menu-widget-menu>.current-menu-item>a',
								
							)
						),
						
						array(
							'id'        => 'townly-text-divider',
							'type'      => 'color',
							'title'     => esc_html__('Dividers: Links/Texts - Color','townly'),
                            'transparent'=> false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '.eleslideinside a.mainbutton.inv,#menu-widget-menu>li>a:hover,#menu-widget-menu>.current-menu-item>a',
							)
						),
						
						array(
							'id'        => 'townly-color-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Background Color','townly'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections etc.','townly'),
                            'transparent'=> false,
							'default'   => '#f8ff31',
							'output'    => array(
								'background-color' => 'a.searchSubmit,.ribbon,.cat_nr,.woocommerce #respond input#submit,.woocommerce a.button,.woocommerce button.button.alt,.woocommerce input.button.alt,.woocommerce a.button.alt,.woocommerce button.button, .woocommerce input.button,#respond #submit,.page-numbers.current,a.mainbutton,#submit,#comments .navigation a,.tagssingle a,input[type=submit],a.comment-reply-link,.item_inn:before,.meta_more a,.owl-nav > div,.page-link>span,.button_div input,button.give-btn-reveal,.give-btn-modal,.give-submit.give-btn,.tmnf_img_box img,.tmnf_single_img .elementor-widget-container',
								'border-color' => 'input.button,button.submit,#sidebar ul.menu a:hover,.page-link>span',
								'color' => '.main-breadcrumbs span:after',
								
							)
						),
						
						array(
							'id'        => 'townly-text-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Links/Texts - Color','townly'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections etc.','townly'),
                            'transparent'=> false,
							'default'   => '#000',
							'output'    => array(
								'color' => 'a.searchSubmit,.ribbon,.ribbon a,.ribbon p,.meta a.ribbon,#footer .ribbon,.cat_nr,.woocommerce #respond input#submit,.woocommerce a.button.alt,.woocommerce input.button.alt,.woocommerce a.button,.woocommerce button.button.alt, .woocommerce button.button, .woocommerce input.button,#comments .reply a,#respond #submit,#footer a.mainbutton,.tmnf_icon,.eleslideinside a.mainbutton,#submit,#comments .navigation a,.tagssingle a,input[type="submit"],a.comment-reply-link,.page-numbers.current,.meta_more a,.owl-next:before,.owl-prev:before,.page-link>span,.button_div input,button.give-btn-reveal,.give-btn-modal,.give-submit.give-btn',
							)
						),
						
						array(
							'id'        => 'townly-hover-color-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Background Hover Color','townly'),
							'subtitle'  => esc_html__('Pick a custom background color for main buttons, special sections etc.','townly'),
                            'transparent'=> false,
							'default'   => '#2a2c44',
							'output'    => array(
								'background-color' => 'a.searchSubmit:hover,.ribbon:hover,a.mainbutton:hover,.entry a.ribbon:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button.alt:hover,.woocommerce a.button:hover, .woocommerce button.button:hover,.woocommerce input.button.alt:hover,.woocommerce input.button:hover,.meta_more a:hover,.owl-nav>div:hover,button.give-btn-reveal:hover,.give-btn-modal:hover,.give-submit.give-btn:hover,.give-btn.give-default-level,input[type=submit]:hover,#main-nav>li.special>a:hover',
								'border-color' => 'input.button:hover,button.submit:hover'
							)
						),
						
						array(
							'id'        => 'townly-hover-text-elements',
							'type'      => 'color',
							'title'     => esc_html__('Elements Links/Texts - Hover Color','townly'),
							'subtitle'  => esc_html__('Pick a custom text color for main buttons, special sections etc.','townly'),
                            'transparent'=> false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '#footer a.mainbutton:hover,.ribbon:hover,.ribbon:hover a,.ribbon a:hover,.entry a.ribbon:hover,a.mainbutton:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover,.meta_more a:hover,.owl-next:hover:before,.owl-prev:hover:before,button.give-btn-reveal:hover,.give-btn-modal:hover,.give-submit.give-btn:hover,.give-btn.give-default-level,input[type=submit]:hover,#main-nav>li.special>a:hover',
							)
						),
						
						
						array(
							'id'        => 'townly-images-bg',
							'type'      => 'color',
							'title'     => esc_html__('Images Background Color','townly'),
							'subtitle'  => esc_html__('Pick a custom background color for theme images.','townly'),
                            'transparent'=> false,
							'default'   => '#282a35',
							'output'    => array(
								'background-color' => '.imgwrap,.post-nav-image,.page-header,.wpm_eleslider .owl-item,.event_item',
							)
						),
						
						
						
						array(
							'id'        => 'townly-images-text',
							'type'      => 'color',
							'title'     => esc_html__('Images Text/Link Color','townly'),
							'subtitle'  => esc_html__('Pick a custom text color for image texts (overlay)','townly'),
                            'transparent'=> false,
							'default'   => '#fff',
							'output'    => array(
								'color' => '.page-header,.page-header a,.page-header h1,.page-header h2,.main-breadcrumbs span,.eleslideinside,.eleslideinside a,.eleslideinside h2,.eleslideinside h3,.event_item,.event_item p,.event_item h2 a',
							)
						),






                    )
					// section end
    ) );
	// other styling THE END
	
	
	

    Redux::setSection( $opt_name, array(
					'type' => 'divide',
    ) );
	
	
	
	
	//POST SETTINGS
    Redux::setSection( $opt_name, array(
                   'title'  => esc_html__( 'Post Settings','townly' ),
                    'icon'   => 'el el-edit',
                    'fields' => array( // header end

						
                        array(
                            'id'       => 'tmnf-post-meta-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Disable "Meta" sections','townly' ),
                            'subtitle' => esc_html__( 'Tick to disable post "inforamtions" - date, category etc. below post titles','townly' ),
                            'default'  => '0'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-likes-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Tags Section','townly' ),
                            'subtitle' => esc_html__( 'Tick to disable likes/tags section in single post page.','townly' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
						
						array(
                            'id'       => 'tmnf-post-nextprev-dis',
                            'type'     => 'checkbox',
                            'title'    => esc_html__( 'Enable Next/Previous Post Section','townly' ),
                            'subtitle' => esc_html__( 'Tick to disable Next/Previous section in single post page.','townly' ),
                            'default'  => '1'// 1 = on | 0 = off
                        ),
                        

                    )
					// section end
    ) );
	// post settings THE END
	
	
	
	

    Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'Social Networks','townly'),
                    'icon'   => 'el el-share',
                    'fields' => array( // header end
				


                        array(
                            'id'       => 'tmnf-social-rss',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Rss Feed','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
                        array(
                            'id'       => 'tmnf-social-facebook',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Facebook','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-twitter',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Twitter','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-pinterest',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Pinterest','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-instagram',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Instagram','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-threads',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Threads','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-youtube',
                            'type'     => 'text',
                            'title'    => esc_html__( 'YouTube','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-vimeo',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Vimeo','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-tumblr',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Tumblr','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-500',
                            'type'     => 'text',
                            'title'    => esc_html__( '500px','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-flickr',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Flickr','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-linkedin',
                            'type'     => 'text',
                            'title'    => esc_html__( 'LinkedIn','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-tripadvisor',
                            'type'     => 'text',
                            'title'    => esc_html__( 'TripAdvisor','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
                        array(
                            'id'       => 'tmnf-social-foursquare',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Foursquare','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-dribbble',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Dribbble','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-skype',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Skype','townly'),
                            'subtitle' => esc_html__( 'Enter skype URL','townly'),
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-stumbleupon',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Stumbleupon','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-github',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Github','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-soundcloud',
                            'type'     => 'text',
                            'title'    => esc_html__( 'SoundCloud','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
												
                        array(
                            'id'       => 'tmnf-social-spotify',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Spotify','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-xing',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Xing','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-whatsapp',
                            'type'     => 'text',
                            'title'    => esc_html__( 'WhatsApp','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-vk',
                            'type'     => 'text',
                            'title'    => esc_html__( 'VK','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-snapchat',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Snapchat','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-telegram',
                            'type'     => 'text',
                            'title'    => esc_html__( 'Telegram','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
												
                        array(
                            'id'       => 'tmnf-social-tiktok',
                            'type'     => 'text',
                            'title'    => esc_html__( 'TikTok','townly'),
                            'subtitle' => esc_html__( 'Enter full URL','townly'),
                            'validate' => 'url',
                        ),
						
						
						


                    )
					// section end
    ) );
	// social networks THE END	
	
	
	
	

    Redux::setSection( $opt_name, array(
					'type' => 'divide',
    ) );


    /*
     * <--- END SECTIONS
     */
